#!/usr/bin/env python

import ROOT
import sys
from array import array

def main():

    # Open file 
    myFile = ROOT.TFile.Open("tree.root")
    if not myFile:
        print("Error: cannot find file tree.root!")
        sys.exit()

    # Open tree
    myTree = myFile.Get("ExampleTree")
    if not myTree:
        print("Error: cannot find tree ExampleTree!")
        sys.exit()

    # Open branch (which contains the data) and set its adress to a variable
    myValue = array('f',[0.])
    myBranch = myTree.GetBranch("gaussian")
    myBranch.SetAddress(myValue)

    # Create histogram
    myHisto = ROOT.TH1F("histo","",100,-5,5)

    # Loop over entries in tree and fill histogram
    nev = myTree.GetEntries()
    for i in range(nev):
        myTree.GetEvent(i)
        myHisto.Fill(myValue[0])
  

    # Create canvas and set its options
    myCanvas = ROOT.TCanvas("plot","plot",500,500)
    myCanvas.SetFillColor(0)
    myCanvas.SetFrameFillColor(0)
    myCanvas.SetBorderMode(0)

    # Set histogram options and draw it
    ROOT.gStyle.SetOptFit(1)
    myHisto.SetLineWidth(2)
    myHisto.SetFillColor(5)
    myHisto.SetXTitle("Value, arbitrary units")
    myHisto.SetYTitle("Entries")
    myHisto.Draw()
    # Make fit
    myHisto.Fit("gaus")
  
    # Save plot as a root macro (could also save as eps/gif/jpg/png/...)
    myCanvas.Print("plot.C")
    myCanvas.Print("plot.png")
    myCanvas.Print("plot.eps")

if __name__=='__main__':
    main()

