#!/usr/bin/env python
import ROOT
import sys
from array import array

def main():

    # Initialize random number generator with a seed    
    ROOT.gRandom.SetSeed(123454321)

    # Define the number of "events"
    N = 1000

    # Open new root file on disk
    myRootFile = ROOT.TFile("tree.root","RECREATE")
    if not myRootFile:
        print("Error: cannot open file tree.root!")
        sys.exit()
  

    # Open root tree
    myRootTree = ROOT.TTree("ExampleTree","tree")
    if not myRootTree:
##        print "Error: cannot create a root tree!"
        sys.exit()
  
    # Create a branch for storing the values from the memory adress
    # of the variable f
    f = array('f',[0.])
    myRootTree.Branch('gaussian',f,'value/F')
  
    # Fill random variables of default gaussian distribution to the root tree 
    for i in range(N):
        f[0] = ROOT.gRandom.Gaus() # mean=0, sigma=1
        #print f[0]
        myRootTree.Fill()

    # Write root tree, delete it from memory, and close it
    myRootTree.Write()
    myRootFile.Close()


if __name__=='__main__':
    main()
